@@ -1,19 +1,19 @@
 import argparse as ap
-from os.path import basename, splitext
 import logging
 import logging.config
+from os.path import basename, splitext
 
-from pymongo import MongoClient
 from prettytable import PrettyTable
+from pymongo import MongoClient
 
 from srsparser import SRSParser
-from srsparser.nlp import NLProcessor
 from srsparser import configs
+from srsparser.nlp import NLProcessor
 
 
 def init_logger() -> logging.Logger:
     logging.config.dictConfig(configs.LOGGING_CONFIG)
-    logger = logging.getLogger('my_logger')
+    logger = logging.getLogger('default')
     return logger
 
 
@@ -113,11 +113,8 @@ def main():
     logger.info('the connection to the results collection ("%s") is established', results_coll.name)
 
     if args.results:
-        logger.info(
-            'documents in results collection ("%s"):\n%s',
-            args.results_coll,
-            [structure['document_name'] for structure in results_coll.find({})]
-        )
+        logger.info('documents in results collection:\n%s',
+                    [structure['document_name'] for structure in results_coll.find({})])
         return
 
     mode = args.mode.lower()
@@ -128,18 +125,16 @@ def main():
         logger.info('the connection to the templates collection ("%s") is established', tmpl_coll.name)
 
         structure_template = tmpl_coll.find_one({'name': args.tmpl})['structure']
-        logger.info('a structure template was obtained from the collection with the results: %s', structure_template)
+        logger.info('a structure template ("%s") was obtained from the collection with the results', args.tmpl)
 
         parser = SRSParser(structure_template)
         document_structure = parser.parse_docx(args.docx_path)
-        logger.info('based on the content of the document ("%s"), a section structure was created: %s', args.docx_path,
-                    document_structure)
+        logger.info('based on the content of the document ("%s"), a section structure was created', args.docx_path)
 
         document_name = splitext(basename(args.docx_path))[0]
 
         results_coll.insert_one({'document_name': document_name, 'structure': document_structure})
-        logger.info('the created section structure is loaded into the results collection ("%s")',
-                    results_coll.name)
+        logger.info('the created section structure is loaded into the results collection')
     elif mode == 'keywords':
         results = list(results_coll.find({}))
 
@@ -176,10 +171,15 @@ def main():
         logger.info('done')
 
         keywords_table = PrettyTable()
-        keywords_table.add_column('TF-IDF', tf_idf_keywords[:10])
-        keywords_table.add_column('Pullenti', pullenti_keywords[:10])
 
-        logger.info('below are the top 10 keywords of the "%s" section of the "%s" document:\n%s',
+        if len(pullenti_keywords) >= len(tf_idf_keywords):
+            keywords_table.add_column('TF-IDF', tf_idf_keywords)
+            keywords_table.add_column('Pullenti', pullenti_keywords[:len(tf_idf_keywords)])
+        else:
+            keywords_table.add_column('TF-IDF', tf_idf_keywords[:len(pullenti_keywords)])
+            keywords_table.add_column('Pullenti', pullenti_keywords)
+
+        logger.info('below are the keywords of the "%s" section of the "%s" document:\n%s',
                     args.section, args.docx_name, keywords_table)
     else:
         logger.error('the mode "%s" does not exist', mode)
